@@ -1,4 +1,4 @@
-# $Id: Recipe.pm 988 2005-09-23 19:53:40Z btrott $
+# $Id$
 
 package Recipe;
 use strict;
@@ -7,11 +7,12 @@ use base qw( Data::ObjectDriver::BaseObject );
 use Data::ObjectDriver::Driver::DBI;
 
 __PACKAGE__->install_properties({
-    columns => [ 'id', 'title' ],
+    columns => [ 'recipe_id', 'title' ],
     datasource => 'recipes',
-    primary_key => 'id',
+    primary_key => 'recipe_id',
     driver => Data::ObjectDriver::Driver::DBI->new(
         dsn      => 'dbi:SQLite:dbname=global.db',
+        reuse_dbh => 1,
     ),
 });
 
